@@ -14,7 +14,10 @@
  * SOFTWARE.
  */
 
-pub extern crate dmntk_evaluator;
+extern crate dmntk_common;
+extern crate dmntk_evaluator;
+extern crate dmntk_feel;
+extern crate dmntk_model;
 #[macro_use]
 extern crate lazy_static;
 
